## IOT JOKE PI

[![](https://img.shields.io/pypi/dw/pyiotjokepi.svg?style=plastic)](https://pypi.org/project/pyiotjokepi/) [![](https://img.shields.io/pypi/v/pyiotjokepi.svg)](https://pypi.org/project/pyiotjokepi/) [![](https://img.shields.io/pypi/format/pyiotjokepi.svg)](https://pypi.org/project/pyiotjokepi/) [![](https://img.shields.io/pypi/status/pyiotjokepi.svg)](https://pypi.org/project/pyiotjokepi/) [![](https://img.shields.io/badge/author-Dhanush-orange.svg)](https://github.com/dazzHere)

Control your devices from [IOT-JOKE](https://iot-joker.firebaseapp.com) by RasperryPi

## Install IOT-JOKE-PI
  `pip install pyiotjokepi --user`
